@@ -2,9 +2,11 @@ import sys
 import struct
 import traceback
 import unittest
+
 sys.path.insert(0, "../../volatility3")
 from volatility3.plugins.windows import scheduled_tasks
 
+
 class TestActionsDecoding(unittest.TestCase):
     def test_decode_exe_action(self):
         # fmt: off
@@ -84,8 +86,7 @@ class TestActionsDecoding(unittest.TestCase):
             self.assertEqual(actions[0].action_type, scheduled_tasks.ActionType.Exe)
         except Exception:
             self.fail(
-                "ActionDecoder.decode should not raise exception:\n%s"
-                % traceback.format_exc()
+                f"ActionDecoder.decode should not raise exception:\n{traceback.format_exc()}"
             )
 
 
